pub struct OptimizedSir {
pub sir: SirProgram,
pub layout_requirements: LayoutRequirements<AbsoluteAddr>,
/* private fields */
}Expand description
A pre-layout compiler artifact whose SIR optimization pipeline has completed successfully.
Construction is restricted to the compiler driver. Physical layout can only be finalized from this phase, preventing unoptimized SIR from accidentally entering a backend.
Fields
sir: SirProgramlayout_requirements: LayoutRequirements<AbsoluteAddr>Implementations
Sourceimpl OptimizedSir
impl OptimizedSir
Sourcepub fn into_laid_out(self, four_state: bool) -> LaidOutProgram
pub fn into_laid_out(self, four_state: bool) -> LaidOutProgram
Finalize the physical state layout and consume the optimized program.
pub fn into_laid_out_with_mode( self, four_state: bool, mode: MemoryLayoutMode, ) -> LaidOutProgram
Sourceimpl OptimizedSir
impl OptimizedSir
Sourcepub fn collect_working_region_addrs(&self) -> FxHashSet<AbsoluteAddr>
pub fn collect_working_region_addrs(&self) -> FxHashSet<AbsoluteAddr>
Collect the set of AbsoluteAddr values that are accessed in the working
region (region != STABLE). These are the only variables that need working
region space.
pub fn collect_sparse_working_region_addrs(&self) -> FxHashSet<AbsoluteAddr>
Methods from Deref<Target = RuntimeProgram>
pub fn get_addr( &self, instance_path: &[(&str, usize)], var_path: &[&str], ) -> Result<AbsoluteAddr, AddrLookupError>
pub fn get_path(&self, addr: &AbsoluteAddr) -> String
pub fn get_variable_info(&self, addr: &AbsoluteAddr) -> Option<&VariableInfo>
pub fn num_events(&self) -> usize