Re-exports for the custom native backend (for testing/integration).
Modules
- backend
- NativeBackend: SimBackend implementation using a custom host backend.
- emit
- x86-64 code emission: MIR + physical register assignment → machine code.
- features
- Host x86-64 feature facts shared by MIR optimization, allocation, and emission.
- isel
- Instruction Selection: lowers SIR (bit-level SSA) to MIR (word-level SSA).
- jit_mem
- JIT memory: load emitted machine code into executable memory and call it.
- memory_
effect - Physical MIR memory effects shared by optimization and allocation.
- mir
- Machine-level IR: word-level SSA with virtual registers.
- mir_
legalize - mir_opt
- MIR optimization passes: run between ISel and regalloc.
- mir_
verify - regalloc
- Verified SSA register allocator based on Braun & Hack’s extended MIN.
- scalar_
pipeline - Transitional scalar pipeline implemented by the x86 backend.
- ssa_
destroy - Verified destruction of MIR SSA phi nodes into edge-local parallel copies.
- x86_slp
- Target-specific x86 SLP selection and XMM register assignment.
Structs
- Appended
Native Image - Result of finding and decoding an image appended to another byte sequence.
- Native
Backend - Native
Code Entry - One callable function in a packed native code image.
- Native
Execution Timing - Time spent inside generated native simulator functions.
- Native
Program Image - Pointer-free native compiler artifact which can be attached to the precompiled Celox runtime.
- Native
Program Instance - One independently mutable instance of a precompiled native program.
- Shared
Native Code - Shared compiled code for the native backend. Can be cloned (via Arc) to create multiple simulator instances that share the same compiled machine code.
Enums
- Native
Image Architecture - Native ISA required by an appended program image.
- Native
Image Container Error - Failure while encoding or discovering a native image container.
- Native
Program Load Error - Failure while discovering or attaching a compiler-produced native image.
- Native
Signal Identity - Source-independent identity shared by reflected handles for one signal.